package demo.travelselector;

import java.awt.Color;
import java.awt.Component;
import java.awt.EventQueue;
import java.awt.Graphics;
import java.text.ParseException;

import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.SwingConstants;
import javax.swing.UIManager;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import de.javasoft.plaf.synthetica.SyntheticaBlackEyeLookAndFeel;
import de.javasoft.swing.JYTabbedPane;

public class TravelSelectorDemo extends JFrame
{
  public static void main(String[] args) throws Exception
  {
    UIManager.setLookAndFeel(new SyntheticaBlackEyeLookAndFeel(){
      @Override
      protected void loadCustomXML() throws ParseException
      {
        loadXMLConfig("/demo/travelselector/selectorTabbedPane.xml");        
      }
    });
    
    EventQueue.invokeLater(new Runnable()
    {      
      public void run()
      {
        new TravelSelectorDemo();
      }
    });
  }
  
  public TravelSelectorDemo()
  {
    add(createTabbedPane());
    
    setDefaultCloseOperation(EXIT_ON_CLOSE);
    setTitle(getClass().getSimpleName());
    setSize(600, 340);
    setLocationRelativeTo(null);
    setVisible(true);
  }
  
  private JTabbedPane createTabbedPane()
  {
    JYTabbedPane tabbedPane = new JYTabbedPane();
    //apply style
    tabbedPane.setName("SelectorTabbedPane");

    tabbedPane.addTab("<html><b>PLANE</b></html>", createPanel("Plane-Panel"));
    tabbedPane.addTab("<html><b>SHIP</b></html>", createPanel("Ship-Panel"));
    tabbedPane.addTab("<html><b>TRAIN</b></html>", createPanel("Train-Panel"));
    tabbedPane.addTab("<html><b>BUS</b></html>", createPanel("Bus-Panel"));
    tabbedPane.addTab("<html><b>CAR</b></html>", createPanel("Car-Panel"));

    //set tab icons
    String[] icons = new String[]{"/demo/travelselector/plane.png", "/demo/travelselector/plane_selected.png",
        "/demo/travelselector/ship.png", "/demo/travelselector/ship_selected.png",
        "/demo/travelselector/train.png", "/demo/travelselector/train_selected.png",
        "/demo/travelselector/bus.png", "/demo/travelselector/bus_selected.png",
        "/demo/travelselector/car.png", "/demo/travelselector/car_selected.png"};    
    for (int i=0; i<tabbedPane.getTabCount(); i++)
    {  
      JLabel l = tabbedPane.getTabLabelAt(i);
      l.setIcon(new TabIcon(tabbedPane, i, icons[i*2], icons[i*2+1]));
      l.setHorizontalTextPosition(SwingConstants.CENTER);
      l.setVerticalTextPosition(SwingConstants.BOTTOM);
    }  

    //update foreground for HTML labels
    tabbedPane.setSelectedIndex(-1);
    tabbedPane.addChangeListener(new ChangeListener()
    {      
      public void stateChanged(ChangeEvent evt)
      {
        JYTabbedPane tabPane = (JYTabbedPane)evt.getSource();
        for (int i = 0; i < tabPane.getTabCount(); i++)
          tabPane.getTabLabelAt(i).setForeground(null);
      }
    });    
    tabbedPane.setSelectedIndex(0);
    return tabbedPane;
  }
  
  private JPanel createPanel(String text)
  {
    JPanel p = new JPanel();
    p.setBackground(new Color(0x3C3C3C));
    p.add(new JLabel(text));
    return p;
  }

  //
  // Icon class to use regular and selected icons for tabs
  //
  private static class TabIcon implements Icon
  {
    private JTabbedPane tabPane;
    private int index;
    private Icon regularIcon;
    private Icon selectedIcon;
    
    public TabIcon(JTabbedPane tabPane, int index, String regularIconPath, String selectedIconPath)
    {
      this.tabPane = tabPane;
      this.index = index;
      this.regularIcon = new ImageIcon(getClass().getResource(regularIconPath));
      this.selectedIcon = new ImageIcon(getClass().getResource(selectedIconPath));
    }
    
    public void paintIcon(Component c, Graphics g, int x, int y)
    {
      if (index == tabPane.getSelectedIndex())
        selectedIcon.paintIcon(c, g, x, y);
      else
        regularIcon.paintIcon(c, g, x, y);
    }

    public int getIconWidth()
    {
      return (index == tabPane.getSelectedIndex()) ? selectedIcon.getIconWidth() : regularIcon.getIconWidth();
    }

    public int getIconHeight()
    {
      return (index == tabPane.getSelectedIndex()) ? selectedIcon.getIconHeight() : regularIcon.getIconHeight();
    }    
  }
}
